@@ -187,7 +187,7 @@ if (! window._OQAjaxQueryLoaded)
   });
 
   $(document).delegate('.OQToolsBut','click', function(){
-    $(".OQToolsPanel").toggle().filter(":visible").each(function(){ this.scrollIntoView(true); });
+    $(".OQToolsPanel").toggle().filter(':visible').find('li:first h3').click();
   });
 
   $(document).delegate('.OQDeleteSavedSearchBut','click', function(){
@@ -340,23 +340,19 @@ if (! window._OQAjaxQueryLoaded)
     return true;
   });
 
-  $(document).delegate('.OQToolExpander', 'click', function() {
-    var $t = $(this);
-    var $content = $t.next('.OQToolContent');
-    if ($content.length==1) {
-      $content.remove();
-      $t.removeClass('opened');
-    } else {
-      $t.siblings('.opened').removeClass('opened');
-      $t.addClass('opened');
-      $t.siblings('.OQToolContent').remove();
-      // load tool content 
-      var $f = $('form.OQform');
-      var dat = buildParamMap($f);
-      dat.module = 'InteractiveQuery2Tools';
-      dat.tool = $t.attr('data-toolkey');
-      $("<div class=OQToolContent />").insertAfter($t).load($f[0].action, dat);
-    }
+  $(document).delegate('.OQToolExpander h3', 'click', function() {
+    var $t = $(this).closest('li');
+    var $content = $t.closest('.OQToolsPanel').find('.OQToolContent');
+    $content.remove();
+    $content.closest('li').removeClass('opened');
+    $t.addClass('opened'); 
+    var $newtoolcontent = $("<div class=OQToolContent />");
+    $t.append($newtoolcontent);
+    var $f = $('form.OQform');
+    var dat = buildParamMap($f);
+    dat.module = 'InteractiveQuery2Tools';
+    dat.tool = $t.attr('data-toolkey');
+    $newtoolcontent.load($f[0].action, dat);
   });
 
   $(document).delegate('.OQFilterDescr', 'click', function() {
@@ -655,8 +651,9 @@ if (! window._OQAjaxQueryLoaded)
         if (val) newfilter += ' '+val;
       }
       else if ($(this).is('input.rexp')) {
-        if (/\"/.test(val)) val = "'"+val+"'";   
-        else val = '"'+val+'"';   
+        if (! /\'/.test(val)) val = "'"+val+"'";
+        else if (! /\"/.test(val)) val = '"'+val+'"';
+        else val = '"'+val.replace(/\"/g,'')+'"';
         newfilter += ' '+val;
       }
       else if (val != '') {
